# CSS/JS Aggregation Retention Module

This module prevents Drupal from deleting all CSS/JS aggregates during cache rebuilds (`drush cr`), instead implementing a time-based garbage collector that only removes stale files.

## Problem

Drupal 10.1's lazy CSS/JS pipeline deletes the entire `/sites/*/files/{css,js}` directories during every cache rebuild. This can cause an issue on statically generated sites that depend on the aggregated CSS and JS files. See <https://www.drupal.org/node/3301716> for details.

## Solution

This module decorates the lazy asset collection optimizers to:

- Keep recent aggregates (default: 45 days)
- Delete only stale files during cache rebuilds
- Provide Drush commands for manual management

## Installation

1. Install the module using Composer: `composer require drupal/css_js_agg_retention`
2. Enable the module: `drush en css_js_agg_retention -y`
3. Clear cache: `drush cr`

## Usage

### Automatic Operation

Once enabled, the module automatically intercepts cache rebuilds and only deletes CSS/JS aggregates older than 45 days.

### Drush Commands

**Purge old files (respects retention threshold):**

```bash
drush css-js-agg-retention:purge-old
# or
drush cjar:purge-old
```

**Purge all files (emergency cleanup):**

```bash
drush css-js-agg-retention:purge-all
# or
drush cjar:purge-all
```

## Configuration

The retention period can be configured via the Config API:

```php
\Drupal::configFactory()
  ->getEditable('css_js_agg_retention.settings')
  ->set('retention_days', 30)
  ->save();
```

## Compatibility

- Drupal 10.1+

## Architecture

The module uses service decorators to intercept the lazy asset collection optimizers:

- `css_js_agg_retention.css_optimizer` decorates `asset.css.collection_optimizer_lazy`
- `css_js_agg_retention.js_optimizer` decorates `asset.js.collection_optimizer_lazy`

## Logging

Purge operations are logged to the `css_js_agg_retention` channel with details about files scanned and deleted.
