<?php

namespace Drupal\css_js_agg_retention\Commands;

use Drush\Commands\DrushCommands;

/**
 * Drush commands for CSS/JS aggregation retention.
 */
class CssJsAggRetentionCommands extends DrushCommands {

  /**
   * Purge files older than threshold.
   *
   * @command css-js-agg-retention:purge-old
   * @aliases cjar:purge-old
   * @usage css-js-agg-retention:purge-old
   */
  public function purgeOld() {
    $this->output()->writeln('Purging old CSS/JS aggregates...');

    // Use the decorated services through their original names.
    \Drupal::service('asset.css.collection_optimizer')->deleteAll();
    \Drupal::service('asset.js.collection_optimizer')->deleteAll();

    $this->output()->writeln('Purge complete.');
  }

  /**
   * Purge everything regardless of age.
   *
   * @command css-js-agg-retention:purge-all
   * @aliases cjar:purge-all
   * @usage css-js-agg-retention:purge-all
   */
  public function purgeAll() {
    $this->output()->writeln('Purging all CSS/JS aggregates...');

    $fs = \Drupal::service('file_system');
    $fs->deleteRecursive('assets://css');
    $fs->deleteRecursive('assets://js');

    $this->output()->writeln('All aggregates purged.');
  }

}
